This package contains variant tools, a command line tool for 
the manipulation, annotation, and analysis of genetic variants
from next-generation sequencing studies. Please refer to 
https://vatlab.github.io/vat-docs/ for details.
